@@ -55,13 +55,10 @@ class PapersWithCodeClient:
         )
 
     @staticmethod
-    def __params(
-        page: int, items_per_page: Optional[int] = None, **kwargs
-    ) -> Dict[str, str]:
+    def __params(page: int, items_per_page: int, **kwargs) -> Dict[str, str]:
         params = {key: str(value) for key, value in kwargs.items()}
         params["page"] = str(page)
-        if items_per_page is not None:
-            params["items_per_page"] = str(items_per_page)
+        params["items_per_page"] = str(items_per_page)
         return params
 
     @staticmethod
@@ -142,70 +139,105 @@ class PapersWithCodeClient:
         """
         return Paper(**self.http.get(f"/papers/{paper_id}/"))
 
+    @handler
+    def paper_dataset_list(
+        self, paper_id: str, page: int = 1, items_per_page: int = 50
+    ) -> Repositories:
+        """Return a list of datasets mentioned in the paper..
+
+        Args:
+            paper_id (str): ID of the paper.
+            page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
+
+        Returns:
+            Datasets: Datasets object.
+        """
+        params = self.__params(page, items_per_page)
+        return self.__page(
+            self.http.get(f"/papers/{paper_id}/datasets/", params=params),
+            Datasets,
+        )
+
     @handler
     def paper_repository_list(
-        self, paper_id: str, page: int = 1
+        self, paper_id: str, page: int = 1, items_per_page: int = 50
     ) -> Repositories:
         """Return a list of paper implementations.
 
         Args:
             paper_id (str): ID of the paper.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             Repositories: Repositories object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(f"/papers/{paper_id}/repositories/", params=params),
             Repositories,
         )
 
     @handler
-    def paper_task_list(self, paper_id: str, page: int = 1) -> Tasks:
+    def paper_task_list(
+        self, paper_id: str, page: int = 1, items_per_page: int = 50
+    ) -> Tasks:
         """Return a list of tasks mentioned in the paper.
 
         Args:
             paper_id (str): ID of the paper.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             Tasks: Tasks object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(f"/papers/{paper_id}/tasks/", params=params), Tasks
         )
 
     @handler
-    def paper_method_list(self, paper_id: str, page: int = 1) -> Methods:
+    def paper_method_list(
+        self, paper_id: str, page: int = 1, items_per_page: int = 50
+    ) -> Methods:
         """Return a list of methods mentioned in the paper.
 
         Args:
             paper_id (str): ID of the paper.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             Methods: Methods object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(f"/papers/{paper_id}/methods/", params=params),
             Methods,
         )
 
     @handler
-    def paper_result_list(self, paper_id: str, page: int = 1) -> Results:
+    def paper_result_list(
+        self, paper_id: str, page: int = 1, items_per_page: int = 50
+    ) -> Results:
         """Return a list of evaluation results for the paper.
 
         Args:
             paper_id (str): ID of the paper.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             Results: Results object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(f"/papers/{paper_id}/results/", params=params),
             Results,
@@ -383,12 +415,9 @@ class PapersWithCodeClient:
         Returns:
             Tasks: Tasks object.
         """
+        params = self.__params(page, items_per_page)
         return self.__page(
-            self.http.get(
-                f"/areas/{area_id}/tasks/",
-                params=self.__params(page, items_per_page),
-            ),
-            Tasks,
+            self.http.get(f"/areas/{area_id}/tasks/", params=params), Tasks
         )
 
     @handler
@@ -483,12 +512,9 @@ class PapersWithCodeClient:
         Returns:
             Tasks: Tasks object.
         """
+        params = self.__params(page, items_per_page)
         return self.__page(
-            self.http.get(
-                f"/tasks/{task_id}/parents/",
-                params=self.__params(page, items_per_page),
-            ),
-            Tasks,
+            self.http.get(f"/tasks/{task_id}/parents/", params=params), Tasks
         )
 
     @handler
@@ -506,12 +532,9 @@ class PapersWithCodeClient:
         Returns:
             Tasks: Tasks object.
         """
+        params = self.__params(page, items_per_page)
         return self.__page(
-            self.http.get(
-                f"/tasks/{task_id}/children/",
-                params=self.__params(page, items_per_page),
-            ),
-            Tasks,
+            self.http.get(f"/tasks/{task_id}/children/", params=params), Tasks
         )
 
     @handler
@@ -529,28 +552,27 @@ class PapersWithCodeClient:
         Returns:
             Papers: Papers object.
         """
+        params = self.__params(page, items_per_page)
         return self.__page(
-            self.http.get(
-                f"/tasks/{task_id}/papers/",
-                params=self.__params(page, items_per_page),
-            ),
-            Papers,
+            self.http.get(f"/tasks/{task_id}/papers/", params=params), Papers
         )
 
     @handler
     def task_evaluation_list(
-        self, task_id: str, page: int = 1
+        self, task_id: str, page: int = 1, items_per_page: int = 50
     ) -> EvaluationTables:
         """Return a list of evaluation tables for a selected task.
 
         Args:
             task_id (str): ID of the task.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             EvaluationTables: EvaluationTables object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(f"/tasks/{task_id}/evaluations/", params=params),
             EvaluationTables,
@@ -644,18 +666,20 @@ class PapersWithCodeClient:
 
     @handler
     def dataset_evaluation_list(
-        self, dataset_id: str, page: int = 1
+        self, dataset_id: str, page: int = 1, items_per_page: int = 50
     ) -> EvaluationTables:
         """Return a list of evaluation tables for a selected dataset.
 
         Args:
             dataset_id (str): ID of the dasaset.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
            EvaluationTables: EvaluationTables object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(
                 f"/datasets/{dataset_id}/evaluations/", params=params
@@ -725,11 +749,9 @@ class PapersWithCodeClient:
         Returns:
             EvaluationTables: Evaluation table page object.
         """
+        params = self.__params(page, items_per_page)
         return self.__page(
-            self.http.get(
-                "/evaluations/", params=self.__params(page, items_per_page)
-            ),
-            EvaluationTables,
+            self.http.get("/evaluations/", params=params), EvaluationTables
         )
 
     @handler
@@ -794,18 +816,20 @@ class PapersWithCodeClient:
 
     @handler
     def evaluation_metric_list(
-        self, evaluation_id: str, page: int = 1
+        self, evaluation_id: str, page: int = 1, items_per_page: int = 50
     ) -> Metrics:
         """List all metrics used in the evaluation table.
 
         Args:
             evaluation_id (str): ID of the evaluation table.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             Metrics: Metrics object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(
                 f"/evaluations/{evaluation_id}/metrics/", params=params
@@ -884,18 +908,20 @@ class PapersWithCodeClient:
 
     @handler
     def evaluation_result_list(
-        self, evaluation_id: str, page: int = 1
+        self, evaluation_id: str, page: int = 1, items_per_page: int = 50
     ) -> Results:
         """List all results from the evaluation table.
 
         Args:
             evaluation_id (str): ID of the evaluation table.
             page (int): Desired page.
+            items_per_page (int): Desired number of items per page.
+                Default: 50.
 
         Returns:
             Results: Results object.
         """
-        params = self.__params(page)
+        params = self.__params(page, items_per_page)
         return self.__page(
             self.http.get(
                 f"/evaluations/{evaluation_id}/results/", params=params
